summaryrefslogtreecommitdiffstats
path: root/src/usr/pnor/spnorrp.C
diff options
context:
space:
mode:
authorJaymes Wilks <mjwilks@us.ibm.com>2017-08-25 14:18:38 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-08-31 12:49:40 -0400
commite1678bffbd5cba43911f7e6f670ac3c3bb68af39 (patch)
tree2f9086aa3a1e29bbc353591c4a3d771c92472d0d /src/usr/pnor/spnorrp.C
parent45d359f3df82a3e9edf31b89193c7a61c5229977 (diff)
downloadtalos-hostboot-e1678bffbd5cba43911f7e6f670ac3c3bb68af39.tar.gz
talos-hostboot-e1678bffbd5cba43911f7e6f670ac3c3bb68af39.zip
Replace HB_SECURITY_MODE attribute with SECUREBOOT API equivalent
The HB_SECURITY_MODE attribute will now be a variable managed by secureboot. The FAPI attribue SECURITY_MODE that maps to the HB version will now call to that variable in the SECUREBOOT API. Change-Id: I7e42c3f2e355feeb0d49aa6a998960bc5409bfa2 RTC:178643 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/45167 Reviewed-by: Michael Baiocchi <mbaiocch@us.ibm.com> Reviewed-by: Nicholas E. Bofferding <bofferdn@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/pnor/spnorrp.C')
-rw-r--r--src/usr/pnor/spnorrp.C9
1 files changed, 3 insertions, 6 deletions
diff --git a/src/usr/pnor/spnorrp.C b/src/usr/pnor/spnorrp.C
index 0b298afeb..c4fae6937 100644
--- a/src/usr/pnor/spnorrp.C
+++ b/src/usr/pnor/spnorrp.C
@@ -803,14 +803,11 @@ errlHndl_t PNOR::unloadSecureSection(const SectionId i_section)
void SPnorRP::processLabOverride(
const sb_flags_t& i_flags) const
{
- TARGETING::Target* pSys = nullptr;
- TARGETING::targetService().getTopLevelTarget(pSys);
- assert(pSys != nullptr,"System target was nullptr.");
- // ATTR_HB_SECURITY_MODE attribute values are inverted with respect to the
+ // Secure boot sbe security mode values are inverted with respect to the
// lab override flag for the same logical meaning
- TARGETING::ATTR_HB_SECURITY_MODE_type securityMode =
+ uint8_t securityMode =
!(i_flags.hw_lab_override);
- pSys->setAttr<TARGETING::ATTR_HB_SECURITY_MODE>(securityMode);
+ SECUREBOOT::setSbeSecurityMode(securityMode);
TRACFCOMP(g_trac_pnor,INFO_MRK "Set lab security override policy to %s.",
securityMode ? "*NO* override" : "override if requested");
}
OpenPOWER on IntegriCloud